@@ -65,7 +65,10 @@ void SuspendSessionConfig::load()
 {
     configGroup().config()->reparseConfiguration();
 
-    uint suspendType = configGroup().readEntry< uint >("suspendType", 0);
+    uint defaultAction = (PowerManagement::instance()->canSuspend() //
+                                                       ? SuspendSession::ToRamMode
+                                                       : SuspendSession::ShutdownMode);
+    uint suspendType = configGroup().readEntry<uint>("suspendType", static_cast<uint>(defaultAction));
     m_comboBox->setCurrentIndex(m_comboBox->findData(suspendType));
     m_idleTime->setValue((configGroup().readEntry<int>("idleTime", 600000) / 60) / 1000);
     if (m_suspendThenHibernateEnabled != nullptr && m_suspendThenHibernateEnabled) {
