@@ -300,7 +300,7 @@ protected:
     void onBrightnessChanged(BrightnessControlType device, int value, int valueMax);
     void setBatteryEnergy(double energy);
     void setBatteryEnergyFull(double energy);
-    void setBatteryRate(double rate);
+    void setBatteryRate(double rate, qulonglong timestamp);
     void setButtonPressed(PowerDevil::BackendInterface::ButtonType type);
     void setAcAdapterState(PowerDevil::BackendInterface::AcAdapterState state);
 
