@@ -24,6 +24,7 @@
 #include "powerdevilaction.h"
 #include "powerdevilactionpool.h"
 #include "powerdevilpolicyagent.h"
+#include "powerdevilpowermanagement.h"
 #include "powerdevilprofilegenerator.h"
 #include "powerdevil_debug.h"
 
@@ -126,8 +127,9 @@ void Core::onBackendReady()
 
         // These are generated profiles,
         const bool mobile = Kirigami::TabletModeWatcher::self()->isTabletMode();
+        const bool vm = PowerDevil::PowerManagement::instance()->isVirtualMachine();
 
-        ProfileGenerator::generateProfiles(mobile, toRam, toDisk);
+        ProfileGenerator::generateProfiles(mobile, vm, toRam, toDisk);
         m_profilesConfig->reparseConfiguration();
     }
 
